@@ -14,7 +14,7 @@ setAs("SpatRaster", "Raster",
 		prj <- crs(from)
 		if (nl == 1) {
 			if (b$source == "") {
-				r <- raster::raster(ncols=ncol(from), nrows=nrow(from), crs=crs(from),
+				r <- raster::raster(ncols=ncol(from), nrows=nrow(from), crs=prj,
 			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
 				if (hasValues(from)) {
 					raster::values(r) <- values(from)
@@ -40,12 +40,18 @@ setAs("SpatRaster", "Raster",
 				x <- raster::raster(ncol=ncol(from), nrow=nrow(from), crs=prj,
 			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
 				r <- list()
-				for (i in 1:nl) {
-					if (b$source[i] == "") {
-						r[[i]] <- raster::setValues(x, values(from[[i]]))
+				b$layer <- 1:nrow(b)
+				for (i in usid) {
+					bi <- b[b$sid == usid[i], ,drop=FALSE]
+					if (bi$source[1] == "") {
+						r[[i]] <- raster::setValues(x, values(from[[ bi$layer ]]))
 					} else {
-						bands <- b$bands[b$sid == i]
-						r[[i]] <- raster::stack(b$source[i], bands=bands)
+						bands <- bi$bands
+						if (length(bands) > 1) {
+							r[[i]] <- raster::stack(b$source[i], bands=bands)
+						} else {
+							r[[i]] <- raster::raster(b$source[i], band=bands)						
+						}
 					}
 				}
 				r <- raster::stack(r)
@@ -53,6 +59,8 @@ setAs("SpatRaster", "Raster",
 		}
 		try(levels(r) <- cats(from), silent=TRUE)
 		try(names(r) <- names(from))
+		crs(r) <- crs(from)
+		extent(r) <- as.vector(ext(from))
 		return(r)
 	}
 )
@@ -63,8 +71,8 @@ setAs("SpatRaster", "Raster",
 
 .fromRasterLayerBrick <- function(from) {
 	 
-	if (raster::fromDisk(from)) {
-		f <- raster::filename(from)
+	if (fromDisk(from)) {
+		f <- filename(from)
 		if (from@file@driver == "netcdf") {
 			v <- attr(from@data, "zvar")
 			r <- rast(f, v)	
@@ -77,29 +85,33 @@ setAs("SpatRaster", "Raster",
 					levels(r) <- levs
 				}
 			}
-			crs(r) <- raster::wkt(from)
+			prj <- comment(from@crs)
+			if (is.null(prj)) {
+				prj <- from@crs@projargs
+			}
+			crs(r) <- prj
+			if (nbands(from) != nlayers(from)) {
+				r <- r[[bandnr(from)]]
+			}
 		}
 		if (from@file@NAchanged) {
 			NAflag(r) <- from@file@nodatavalue
 		}
 	} else {
-		crsobj <- from@crs
-		if (is.na(crsobj)) {
+		if (is.na(from@crs)) {
 			prj <- ""
 		} else {
-			crscom <- comment(crsobj)
-			if (is.null(crscom)) {
-				prj <- crsobj@projargs
-			} else {
-				prj <- crscom
+			prj <- comment(from@crs)
+			if (is.null(prj)) {
+				prj <- from@crs@projargs
 			}
 		}
 		r <- rast(	nrows=nrow(from), 
 					ncols=ncol(from),
-					nlyrs=raster::nlayers(from),
+					nlyrs=nlayers(from),
 					crs=prj,
-					extent=raster::extent(from))
-		if (raster::hasValues(from)) {
+					extent=extent(from))
+		if (hasValues(from)) {
 			values(r) <- values(from)
 		}
 		levs <- levels(from)[[1]]
@@ -107,45 +119,56 @@ setAs("SpatRaster", "Raster",
 			levels(r) <- levs				
 		}
 	}
-	names(r)  <- names(from)
 	r
 }
 
 .fromRasterStack <- function(from) {
-	x <- from[[1]]
-	n <- raster::nbands(x)
-	nl <- raster::nlayers(from)
-	if ((n > 1) & (n == nl)) {
-		ff <- lapply(1:nl, function(i) { raster::filename(from[[i]]) })
-		if (length(unique(ff)) == 1) {
-			r <- rast(raster::filename(x))
-			return(r)
+	nl <- nlayers(from)
+	ff <- sapply(1:nl, function(i) { filename(from[[i]]) })
+	uff <- unique(ff)
+	if (length(uff) == 1) {
+		if (uff == "") {
+			return(.fromRasterLayerBrick(from))
+		} else {
+			n <- nbands(from[[1]])
+			bnr <- sapply(1:nl, function(i) { bandnr(from[[i]]) })
+			if ((n == nl) && all(bnr == 1:n)) {
+				return( rast(uff) )
+			}
 		}
 	} 
-	s <- lapply(1:raster::nlayers(from), function(i) {
+	s <- lapply(1:nlayers(from), function(i) {
 		x <- from[[i]]
-		.fromRasterLayerBrick(x)[[raster::bandnr(x)]]
+		.fromRasterLayerBrick(x)
 	})
-	s <- do.call(c, s)
-	names(s) <- names(from)
-	s
+	do.call(c, s)
 }
 
 
 setAs("Raster", "SpatRaster", 
 	function(from) {
 		if (inherits(from, "RasterLayer") || inherits(from, "RasterBrick")) { 
-			.fromRasterLayerBrick(from)
+			x <- .fromRasterLayerBrick(from)
 		} else {
-			.fromRasterStack(from)
+			x <- .fromRasterStack(from)
 		}
+		# they may have been changed for file based objects
+		if (is.na(from@crs)) {
+			prj <- ""
+		} else {
+			prj <- comment(from@crs)
+			if (is.null(prj)) {
+				prj <- from@crs@projargs
+			}
+		}
+		crs(x) <- prj
+		names(x) <- names(from)
+		ext(x) <- as.vector(extent(from))
+		x
 	}
 )
 
 
-
-
-
 # To sp pixel/grid objects	
 
 
@@ -595,3 +618,5 @@ setAs("grf", "RasterLayer",
 	# }	
 	# b
 # }
+
+
