@@ -13,7 +13,7 @@
 	if (is.open) {
 		nc <- x@file@con
 	} else {
-		nc <- ncdf4::nc_open(x@file@name)
+		nc <- ncdf4::nc_open(x@file@name, suppress_dimvals = TRUE)
 		on.exit( ncdf4::nc_close(nc) )		
 	}
 	
@@ -112,7 +112,7 @@
 	if (is.open) {
 		nc <- x@file@con
 	} else {
-		nc <- ncdf4::nc_open(x@file@name)
+		nc <- ncdf4::nc_open(x@file@name, suppress_dimvals = TRUE)
 		on.exit( ncdf4::nc_close(nc) )		
 	}
 	zvar <- x@data@zvar
@@ -124,7 +124,10 @@
 		} else {
 			start <- c(col, row, layer, x@data@level)
 			count <- c(ncols, nrows, nn, 1)
-		}		
+		}	
+	} else if (nc$var[[zvar]]$ndims == 2) {
+		start <- c(col, row)
+		count <- c(ncols, nrows)		
 	} else {
 		start <- c(col, row, layer)
 		count <- c(ncols, nrows,  nn)
