@@ -6,7 +6,7 @@
 
 rasterFromCells <- function(x, cells, values=TRUE) {
 	x <- raster(x)
-	u <- unique(cells)
+	u <- stats::na.omit(unique(cells))  # now removing NAs 2018-02-22
 	u <- u[ u > 0 & u <= ncell(x) ]
 	if (length(u) == 0) {
 		stop('no valid cells')
