@@ -18,7 +18,7 @@ function(x, y, ...) {
 
 	yy <- list(y, ...)
 	for (y in yy) {
-		if (! identical( sp::proj4string(x),  sp::proj4string(y)) ) {
+		if (! identical( .proj4string(x), .proj4string(y)) ) {
 			if (!haswarned) {
 				warning('non identical crs')
 				haswarned <- TRUE
