@@ -26,6 +26,8 @@
 	cv <- list()
 	obj <- raster(object) 
 # ?	centralcells <- cellFromXY(obj, xy)
+
+# needs to deal with global wrapping....
 	if (couldBeLonLat(obj)) { 
 		# from m to degrees
 		bufy <- buffer / 111319.5
@@ -198,6 +200,8 @@
 	}
 	
 	if (! is.null(fun)) {
+	
+		fun <- match.fun(fun)
 		if (na.rm) {
 			fun2 <- function(x){
 						x <- stats::na.omit(x)
