@@ -4,12 +4,6 @@
 # Licence GPL v3
 
 
-if (!isGeneric("zonal")) {
-	setGeneric("zonal", function(x, z, ...)
-		standardGeneric("zonal"))
-}	
-
-
 
 setMethod('zonal', signature(x='RasterLayer', z='RasterLayer'), 
 	function(x, z, fun='mean', digits=0, na.rm=TRUE, ...) {
@@ -72,7 +66,7 @@ setMethod('zonal', signature(x='RasterLayer', z='RasterLayer'),
 			
 		} else {
 		
-			if (class(fun) != 'character') {
+			if (!inherits(fun, 'character')) {
 				stop("RasterLayers cannot be processed in memory.\n You can use fun='sum', 'mean', 'sd', 'min', 'max', or 'count' but not a function")
 			}
 			if (! fun %in% c('sum', 'mean', 'sd', 'min', 'max', 'count')) {
@@ -234,7 +228,7 @@ setMethod('zonal', signature(x='RasterStackBrick', z='RasterLayer'),
 			
 		} else {
 		
-			if (class(fun) != 'character') {
+			if (!inherits(fun, 'character')) {
 				stop("RasterLayers cannot be processed in memory.\n You can use fun='sum', 'mean', 'sd', 'min', 'max', or 'count' but not a function")
 			}
 			if (! fun %in% c('sum', 'mean', 'sd', 'min', 'max', 'count')) {
